/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.bo;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
@Entity
@Table(name="DASHBOARD", uniqueConstraints=@UniqueConstraint(columnNames="dashboardName"))
public class Dashboard {

	@Id
	@GeneratedValue
	@Column(name="dashboardId")
	protected Long mId;
	
	@Basic
	@Column(name="dashboardName")
	protected String mName;
	
	@Basic
	@Column(name="dashboardHidden")
	protected Boolean mHidden;
	
	@ManyToOne
	@JoinColumn(name="reportCatId")
	protected ReportCategory mCategory;
	
	@OneToMany(fetch = FetchType.EAGER, cascade=CascadeType.ALL, mappedBy="mDashboard")
	protected Set<ReportParam> mParams = new HashSet<ReportParam>();

	@OneToMany(fetch = FetchType.EAGER, cascade=CascadeType.ALL, mappedBy="mDashboard")
	protected Set<DashboardColumn> mColumns = new HashSet<DashboardColumn>();

	/**
	 * @return the dashboardId
	 */
	public Long getId() {
		return mId;
	}

	/**
	 * @param dashboardId the dashboardId to set
	 */
	public void setId(Long dashboardId) {
		this.mId = dashboardId;
	}

	/**
	 * @return the dashboardName
	 */
	public String getName() {
		return mName;
	}

	/**
	 * @param dashboardName the dashboardName to set
	 */
	public void setName(String dashboardName) {
		this.mName = dashboardName;
	}

	/**
	 * @return the reportCategory
	 */
	public ReportCategory getCategory() {
		return mCategory;
	}

	/**
	 * @param reportCategory the reportCategory to set
	 */
	public void setCategory(ReportCategory reportCategory) {
		this.mCategory = reportCategory;
	}

	/**
	 * @return the dashboardParams
	 */
	public Set<ReportParam> getParams() {
		return mParams;
	}

	/**
	 * @param dashboardParams the dashboardParams to set
	 */
	public void setParams(Set<ReportParam> dashboardParams) {
		this.mParams = dashboardParams;
	}

	/**
	 * @return the dashboardColumns
	 */
	public Set<DashboardColumn> getColumns() {
		return mColumns;
	}

	/**
	 * @param dashboardColumns the dashboardColumns to set
	 */
	public void setColumns(Set<DashboardColumn> dashboardColumns) {
		this.mColumns = dashboardColumns;
	}

	/**
     * @return the hidden
     */
    public Boolean getHidden()
    {
    	return mHidden;
    }

	/**
     * @param hidden the hidden to set
     */
    public void setHidden(Boolean hidden)
    {
    	mHidden = hidden;
    }
}
