/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.bo;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
@Entity
@Table(name="DASHREPORT")
public class DashboardReport {

	@Id
	@GeneratedValue
	@Column(name="dashboardReportId")
	protected Long mId;
	
	@ManyToOne
	@JoinColumn(name = "reportId")
	protected Report mReport;
	
	@Basic
	@Column(name="dashReportTitle")
	protected String mTitle;
	
	@Basic
	@Column(name="dashReportRowIdx")
	protected Integer mRowIndex;
	
	@Basic
	@Column(name="dashReportHeight")
	protected Integer mHeight;
	
	@ManyToOne
	@JoinColumn(name = "dashColId")
	protected DashboardColumn mDashboardColumn;
	
	@OneToMany(fetch = FetchType.EAGER, cascade=CascadeType.ALL, mappedBy="mDashboardReport")
	protected Set<DashboardParamBinding> mDashboardParamBindings = new HashSet<DashboardParamBinding>();

	/**
	 * @return the dashboardReportId
	 */
	public Long getId() {
		return mId;
	}

	/**
	 * @param dashboardReportId the dashboardReportId to set
	 */
	public void setId(Long dashboardReportId) {
		this.mId = dashboardReportId;
	}

	/**
	 * @return the report
	 */
	public Report getReport() {
		return mReport;
	}

	/**
	 * @param report the report to set
	 */
	public void setReport(Report report) {
		this.mReport = report;
	}

	/**
	 * @return the dashboardColumn
	 */
	public DashboardColumn getDashboardColumn() {
		return mDashboardColumn;
	}

	/**
	 * @param dashboardColumn the dashboardColumn to set
	 */
	public void setDashboardColumn(DashboardColumn dashboardColumn) {
		this.mDashboardColumn = dashboardColumn;
	}

	/**
	 * @return the dashboardParamBindings
	 */
	public Set<DashboardParamBinding> getDashboardParamBindings() {
		return mDashboardParamBindings;
	}

	/**
	 * @param dashboardParamBindings the dashboardParamBindings to set
	 */
	public void setDashboardParamBindings(Set<DashboardParamBinding> dashboardParamBindings) {
		this.mDashboardParamBindings = dashboardParamBindings;
	}

	/**
	 * @return the rowIndex
	 */
	public Integer getRowIndex() {
		return mRowIndex;
	}

	/**
	 * @param rowIndex the rowIndex to set
	 */
	public void setRowIndex(Integer rowIndex) {
		this.mRowIndex = rowIndex;
	}

	/**
	 * @return the height
	 */
	public Integer getHeight() {
		return mHeight;
	}

	/**
	 * @param height the height to set
	 */
	public void setHeight(Integer height) {
		this.mHeight = height;
	}

	/**
	 * @return the reportTitle
	 */
	public String getTitle() {
		return mTitle;
	}

	/**
	 * @param reportTitle the reportTitle to set
	 */
	public void setTitle(String reportTitle) {
		this.mTitle = reportTitle;
	}
}
