/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.bo;

import java.util.Collection;
import java.util.HashSet;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinTable;
import javax.persistence.ManyToMany;
import javax.persistence.ManyToOne;
import javax.persistence.Table;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
@Entity
@Table(name="ENV")
public class Environment {
	
	@Id
	@GeneratedValue
	@Column(name="envId")
	protected Long mId;

	@Basic
	@Column(name="envCode")
	protected String mCode;
	
	@Basic
	@Column(name="envName")
	protected String mName;
	
	@ManyToMany
	@JoinTable(name="EnvHostAssoc", joinColumns = @JoinColumn(name="envId", referencedColumnName = "envId"), inverseJoinColumns = @JoinColumn(name="hostId", referencedColumnName = "hostId"))
	protected Collection<Host> mHosts = new HashSet<Host>();
	
	@ManyToOne
	@JoinColumn(name="orgId")
	protected Organization mOrganization;

	/**
	 * @return the environmentId
	 */
	public Long getId() {
		return mId;
	}

	/**
	 * @param environmentId the environmentId to set
	 */
	public void setId(Long environmentId) {
		this.mId = environmentId;
	}

	/**
	 * @return the environmentCode
	 */
	public String getCode() {
		return mCode;
	}

	/**
	 * @param environmentCode the environmentCode to set
	 */
	public void setCode(String environmentCode) {
		this.mCode = environmentCode;
	}

	/**
	 * @return the environmentName
	 */
	public String getName() {
		return mName;
	}

	/**
	 * @param environmentName the environmentName to set
	 */
	public void setName(String environmentName) {
		this.mName = environmentName;
	}

	/**
	 * @return the hosts
	 */
	public Collection<Host> getHosts() {
		return mHosts;
	}

	/**
	 * @param mHosts the hosts to set
	 */
	public void setHosts(Collection<Host> h) {
		mHosts = h;
	}

	/**
	 * @return the organization
	 */
	public Organization getOrganization() {
		return mOrganization;
	}

	/**
	 * @param organization the organization to set
	 */
	public void setOrganization(Organization organization) {
		this.mOrganization = organization;
	}
	
	
}
