/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.bo;

import java.sql.Timestamp;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.EntityListeners;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.Lob;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Transient;
import javax.persistence.UniqueConstraint;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
@Entity
@Table(name="REPORT", uniqueConstraints=@UniqueConstraint(columnNames="reportName"))
@EntityListeners(ReportEntityListener.class)
public class Report {
	
	protected static Log sLog = LogFactory.getLog(Report.class);

	@Id
	@GeneratedValue
	@Column(name="reportId")
	protected Long mId;
	
	@Basic
	@Column(name="reportName")
	protected String mName;
	
	@Basic
	@Column(name="reportHidden")
	protected Boolean mHidden;
	
	@ManyToOne
	@JoinColumn(name = "reportSystemId")
	protected ReportingSystem mReportingSystem;
	
	@ManyToOne
	@JoinColumn(name = "reportCatId")
	protected ReportCategory mCategory;
	
	@OneToMany(fetch = FetchType.EAGER, cascade=CascadeType.ALL, mappedBy="mReport")
	protected Set<ReportParam> mParams = new HashSet<ReportParam>();
	
	@Lob @Basic(fetch=FetchType.EAGER)
	@Column(name="reportContent", length=104857600)
	protected byte[] mZippedReportContent;
	
	@Transient
	protected byte[] mReportContent;
	
	@Basic
	@Column(name="lastUpdate")
	protected Timestamp mLastUpdate = new Timestamp(System.currentTimeMillis());
	
	/**
	 * @return the reportId
	 */
	public Long getId() {
		return mId;
	}

	/**
	 * @param reportId the reportId to set
	 */
	public void setId(Long reportId) {
		this.mId = reportId;
	}

	/**
	 * @return the reportName
	 */
	public String getName() {
		return mName;
	}

	/**
	 * @param reportName the reportName to set
	 */
	public void setName(String reportName) {
		this.mName = reportName;
	}

	/**
	 * @return the reportingSystem
	 */
	public ReportingSystem getReportingSystem() {
		return mReportingSystem;
	}

	/**
	 * @param reportingSystem the reportingSystem to set
	 */
	public void setReportingSystem(ReportingSystem reportingSystem) {
		this.mReportingSystem = reportingSystem;
	}

	/**
	 * @return the reportCategory
	 */
	public ReportCategory getCategory() {
		return mCategory;
	}

	/**
	 * @param reportCategory the reportCategory to set
	 */
	public void setCategory(ReportCategory reportCategory) {
		this.mCategory = reportCategory;
	}

	/**
	 * @return the reportParams
	 */
	public Set<ReportParam> getParams() {
		return mParams;
	}

	/**
	 * @param reportParams the reportParams to set
	 */
	public void setParams(Set<ReportParam> reportParams) {
		this.mParams = reportParams;
	}

	/**
	 * @return the reportContent
	 */
	public byte[] getReportContent() {
		return mReportContent;
	}

	/**
	 * @param reportContent the reportContent to set
	 */
	public void setReportContent(byte[] reportContent) {
		this.mReportContent = reportContent;
	}

	/**
	 * @return the zippedReportContent
	 */
	public byte[] getZippedReportContent() {
		return mZippedReportContent;
	}

	/**
	 * @param zippedReportContent the zippedReportContent to set
	 */
	public void setZippedReportContent(byte[] zippedReportContent) {
		mZippedReportContent = zippedReportContent;
	}

	/**
     * @return the lastUpdate
     */
    public Timestamp getLastUpdate()
    {
    	return mLastUpdate;
    }

	/**
     * @param lastUpdate the lastUpdate to set
     */
    public void setLastUpdate(Timestamp lastUpdate)
    {
    	mLastUpdate = lastUpdate;
    }

	/**
     * @return the hidden
     */
    public Boolean getHidden()
    {
    	return mHidden;
    }

	/**
     * @param hidden the hidden to set
     */
    public void setHidden(Boolean hidden)
    {
    	mHidden = hidden;
    }
}
