/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.server.bo.scheduler;

import java.util.HashSet;
import java.util.Set;

import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

import org.hibernate.annotations.Cascade;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
@Entity
@Table(name="SCH_JOB_SCH")
public class JobSchedule {
	
	@Id
	@GeneratedValue
	@Column(name="jobSchId")
	protected Long mId;
	
	@ManyToOne
	@JoinColumn(name="jobDeclId")
	protected JobDeclaration mJobDeclaration;

	@Basic
	@Column(name="jobSchCronExpr")
	protected String mCronExpression;
	
	@OneToMany(fetch = FetchType.EAGER, cascade=CascadeType.ALL, mappedBy="mJobSchedule")
	@Cascade({org.hibernate.annotations.CascadeType.DELETE_ORPHAN})
	protected Set<JobScheduleParam> mParams = new HashSet<JobScheduleParam>();

	@OneToMany(fetch = FetchType.LAZY, cascade=CascadeType.ALL, mappedBy="mJobSchedule")
	protected Set<JobExecution> mJobExecutions = new HashSet<JobExecution>();

	/**
     * @return the id
     */
    public Long getId()
    {
    	return mId;
    }

	/**
     * @param id the id to set
     */
    public void setId(Long id)
    {
    	mId = id;
    }

	/**
     * @return the jobDeclaration
     */
    public JobDeclaration getJobDeclaration()
    {
    	return mJobDeclaration;
    }

	/**
     * @param jobDeclaration the jobDeclaration to set
     */
    public void setJobDeclaration(JobDeclaration jobDeclaration)
    {
    	mJobDeclaration = jobDeclaration;
    }

	/**
     * @return the cronExpression
     */
    public String getCronExpression()
    {
    	return mCronExpression;
    }

	/**
     * @param cronExpression the cronExpression to set
     */
    public void setCronExpression(String cronExpression)
    {
    	mCronExpression = cronExpression;
    }

	/**
     * @return the params
     */
    public Set<JobScheduleParam> getParams()
    {
    	return mParams;
    }

	/**
     * @param params the params to set
     */
    public void setParams(Set<JobScheduleParam> params)
    {
    	mParams = params;
    }

	/**
     * @return the jobExecutions
     */
    public Set<JobExecution> getJobExecutions()
    {
    	return mJobExecutions;
    }

	/**
     * @param jobExecutions the jobExecutions to set
     */
    public void setJobExecutions(Set<JobExecution> jobExecutions)
    {
    	mJobExecutions = jobExecutions;
    }
}
